@@ -33,7 +33,7 @@ use twilight_model::{
         NumberCommandOptionData, OptionsCommandOptionData,
     },
     channel::ChannelType,
-    id::{ApplicationId, CommandId, CommandVersionId, GuildId},
+    id::{CommandVersionId, GuildId},
 };
 
 /// Builder to create a [`Command`].
@@ -66,15 +66,6 @@ impl CommandBuilder {
         self.0
     }
 
-    /// Set the application ID of the command.
-    ///
-    /// Defaults to [`None`].
-    pub const fn application_id(mut self, application_id: ApplicationId) -> Self {
-        self.0.application_id = Some(application_id);
-
-        self
-    }
-
     /// Set the guild ID of the command.
     ///
     /// Defaults to [`None`].
@@ -93,15 +84,6 @@ impl CommandBuilder {
         self
     }
 
-    /// Set the ID of the command.
-    ///
-    /// Defaults to [`None`].
-    pub const fn id(mut self, id: CommandId) -> Self {
-        self.0.id = Some(id);
-
-        self
-    }
-
     /// Add an option to the command.
     ///
     /// Defaults to an empty list.
@@ -581,11 +563,11 @@ impl SubCommandGroupBuilder {
         CommandOption::SubCommandGroup(self.0)
     }
 
-    /// Add a sub command option to the sub command group.
+    /// Set the list of sub commands to the group.
     ///
-    /// Defaults to an empty list.
-    pub fn option(mut self, option: SubCommandBuilder) -> Self {
-        self.0.options.push(option.into());
+    /// Defaults to no subcommands.
+    pub fn subcommands(mut self, subcommands: impl IntoIterator<Item = SubCommandBuilder>) -> Self {
+        self.0.options = subcommands.into_iter().map(Into::into).collect();
 
         self
     }
@@ -663,7 +645,7 @@ mod tests {
         )
         .option(
             SubCommandGroupBuilder::new("user".into(), "Get or edit permissions for a user".into())
-                .option(
+                .subcommands([
                     SubCommandBuilder::new("get".into(), "Get permissions for a user".into())
                         .option(
                             UserBuilder::new("user".into(), "The user to get".into())
@@ -675,8 +657,6 @@ mod tests {
                              will be returned"
                                 .into(),
                         )),
-                )
-                .option(
                     SubCommandBuilder::new("edit".into(), "Edit permissions for a user".into())
                         .option(
                             UserBuilder::new("user".into(), "The user to edit".into())
@@ -688,11 +668,11 @@ mod tests {
                              will be edited"
                                 .into(),
                         )),
-                ),
+                ]),
         )
         .option(
             SubCommandGroupBuilder::new("role".into(), "Get or edit permissions for a role".into())
-                .option(
+                .subcommands([
                     SubCommandBuilder::new("get".into(), "Get permissions for a role".into())
                         .option(
                             RoleBuilder::new("role".into(), "The role to get".into())
@@ -704,8 +684,6 @@ mod tests {
                              will be returned"
                                 .into(),
                         )),
-                )
-                .option(
                     SubCommandBuilder::new("edit".into(), "Edit permissions for a role".into())
                         .option(
                             RoleBuilder::new("role".into(), "The role to edit".into())
@@ -724,7 +702,7 @@ mod tests {
                             )
                             .autocomplete(true),
                         ),
-                ),
+                ]),
         )
         .build();
 
